@extends('layouts.app')
@section('htmlheader_title')
	Stats
@endsection

@section('content')
	<div class="row">
		<div class="col-12">
			<h2>Network Status</h2>
		</div>
	</div>

	<div class="row">
		<div class="col-12">
			<p>Nodes with uncollected mail as at <strong class="highlight">{{ $date }}</strong>:</p>

			<table class="table monotable w-100" id="mailfiles">
				<thead>
				<tr>
					<th>Network</th>
					<th>System</th>
					<th>Address</th>
					<th class="text-right">Echomails</th>
					<th class="text-right">Netmails</th>
					<th class="text-right">Files</th>
					<th>Last Session</th>
					<th>Poll Mode</th>
					<th>Auto Hold</th>
				</tr>
				</thead>

				<tbody>
				@foreach($uncollected as $o)
					<tr>
						<td>{{ $o->zone->domain->name }}</td>
						<td>
							<a href="{{ url('system/addedit',$o->system_id) }}">{{ $o->system->name }}</a>
							@if (($x=$o->parent()) && ($x->id !== $o->id))
								<br><small>[via <a href="{{ url('system/addedit',$x->system_id) }}">{{ $x->ftn4d }}</a>]</small>
							@endif
						</td>
						<td>{{ $o->ftn4d }}</td>
						<td class="text-right">{{ number_format($o->uncollected_echomail ?? 0) }}</td>
						<td class="text-right">{{ number_format($o->uncollected_netmail ?? 0) }}</td>
						<td class="text-right">{{ number_format($o->uncollected_files ?? 0) }}</td>
						<td>{{ $o->system->last_session?->format('Y-m-d H:i') }}</td>
						<td>{{ is_null($o->system->pollmode) ? 'HOLD' : ($o->system->pollmode ? 'CRASH' : 'DAILY') }}</td>
						<td>{{ $o->system->autohold ? 'YES' : 'NO' }}</td>
					</tr>
				@endforeach
				</tbody>
			</table>
		</div>
	</div>
@endsection

@section('page-css')
	@css('datatables')
@append
@section('page-scripts')
	@js('datatables')

	<script type="text/javascript">
		$(document).ready(function() {
			$('#mailfiles').DataTable({
				paging: true,
				pageLength: 25,
				searching: true,
				orderFixed: [0,'asc'],
				order: [[1,'asc']],
				conditionalPaging: {
					style: 'fade',
					speed: 500
				},
				rowGroup: {
					dataSrc: [0],
				},
				columnDefs: [
					{
						targets: [0],
						visible: false,
					},
				],
				language: {
					paginate: {
						previous: '&lt;&lt;',
						next: '&gt;&gt;'
					}
				}
			});
		});
	</script>
@append